# -*- coding: utf-8 -*-


class CampoInexistenteError(object):

    def exibirErro(self, name):
        return 'Este campo ' + name + ' não existe neste bloco de registros!'

class BlocoInexistenteError(object):

    def exibirErro(self, name):
        return 'Este bloco ' + name + ' não existe neste arquivo!'


# -*- coding: utf-8 -*-


class Campo(object):

    def __init__(self, indice, inicio, nome, bloco, tamanho):
        self._indice = indice
        self._nome = nome
        self._valor = bloco[inicio:inicio+tamanho]





# -*- coding: utf-8 -*-
from registrosDados import *
from bloco import Bloco


class pendenciasInternas(Bloco):

    def __init__(self):
        self.blocos = []
        self.nome = "pendenciasInternas"


class pendenciasFinanceiras(Bloco):

    def __init__(self):
        self.blocos = []
        self.nome = "pendenciasFinanceiras"


class protestosEstados(Bloco):

    def __init__(self):
        self.blocos = []
        self.nome = "protestosEstados"


class chequesSemFundos(Bloco):

    def __init__(self):
        self.blocos = []
        self.nome = "chequesSemFundos"


class blocoB49C(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros do Protocolo"
        self.nome = nome
        self.campos = RegistrosB49C(bloco)


class blocoP002(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros adicionais ao Protocolo"
        self.nome = nome
        self.campos = RegistrosP002(bloco)


class blocoN001(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros adicionais ao Protocolo"
        self.nome = nome
        self.campos = RegistrosN001(bloco)


class blocoN002_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros adicionais ao Protocolo"
        self.nome = nome
        self.campos = RegistrosN002_subtipo00(bloco)

class blocoN002_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros adicionais ao Protocolo"
        self.nome = nome
        self.campos = RegistrosN002_subtipo01(bloco)


class blocoN003(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registros adicionais ao Protocolo"
        self.nome = nome
        self.campos = RegistrosN003(bloco)


class blocoN200_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Bloco de informações do Confirmei"
        self.nome = nome
        self.campos = RegistrosN200_subtipo00(bloco)


class blocoN200_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Bloco de informações do Confirmei"
        self.nome = nome
        self.campos = RegistrosN200_subtipo01(bloco)


class blocoN210_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Alerta de Documentos Roubados"
        self.nome = nome
        self.campos = RegistrosN210_subtipo00(bloco)


class blocoN210_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Alerta de Documentos Roubados"
        self.nome = nome
        self.campos = RegistrosN210_subtipo01(bloco)


class blocoN210_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Alerta de Documentos Roubados"
        self.nome = nome
        self.campos = RegistrosN210_subtipo99(bloco)


class blocoN220(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Nada Consta"
        self.nome = nome
        self.campos = RegistrosN220(bloco)


class blocoN230_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendencias Internas"
        self.nome = nome
        self.campos = RegistrosN230_subtipo00(bloco)


class blocoN230_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendencias Internas"
        self.nome = nome
        self.campos = RegistrosN230_subtipo90(bloco)


class blocoN230_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendencias Internas"
        self.nome = nome
        self.campos = RegistrosN230_subtipo99(bloco)


class blocoN240_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendências Financeiras"
        self.nome = nome
        self.campos = RegistrosN240_subtipo00(bloco)


class blocoN240_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendências Financeiras"
        self.nome = nome
        self.campos = RegistrosN240_subtipo01(bloco)


class blocoN240_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendências Financeiras"
        self.nome = nome
        self.campos = RegistrosN240_subtipo90(bloco)


class blocoN240_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Pendências Financeiras"
        self.nome = nome
        self.campos = RegistrosN240_subtipo99(bloco)


class blocoN250_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Protestos do Estado"
        self.nome = nome
        self.campos = RegistrosN250_subtipo00(bloco)


class blocoN250_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Protestos do Estado"
        self.nome = nome
        self.campos = RegistrosN250_subtipo01(bloco)


class blocoN250_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Protestos do Estado"
        self.nome = nome
        self.campos = RegistrosN250_subtipo90(bloco)


class blocoN250_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Protestos do Estado"
        self.nome = nome
        self.campos = RegistrosN250_subtipo99(bloco)


class blocoN270_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Cheques sem fundos - Bacen"
        self.nome = nome
        self.campos = RegistrosN270_subtipo00(bloco)


class blocoN270_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Cheques sem fundos - Bacen"
        self.nome = nome
        self.campos = RegistrosN270_subtipo90(bloco)


class blocoN270_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Cheques sem fundos - Bacen"
        self.nome = nome
        self.campos = RegistrosN270_subtipo99(bloco)


class blocoN300_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Recheque Online"
        self.nome = nome
        self.campos = RegistrosN300_subtipo00(bloco)


class blocoN300_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Recheque Online"
        self.nome = nome
        self.campos = RegistrosN300_subtipo01(bloco)


class blocoN300_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Recheque Online"
        self.nome = nome
        self.campos = RegistrosN300_subtipo99(bloco)


class blocoN310_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Recheque"
        self.nome = nome
        self.campos = RegistrosN310_subtipo00(bloco)


class blocoN310_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Recheque"
        self.nome = nome
        self.campos = RegistrosN310_subtipo99(bloco)


class blocoN320_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Contumácia"
        self.nome = nome
        self.campos = RegistrosN320_subtipo00(bloco)


class blocoN320_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Contumácia"
        self.nome = nome
        self.campos = RegistrosN320_subtipo90(bloco)


class blocoN320_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Contumácia"
        self.nome = nome
        self.campos = RegistrosN320_subtipo99(bloco)


class blocoN330_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Histórico do Cheque - Feature REAC"
        self.nome = nome
        self.campos = RegistrosN330_subtipo00(bloco)


class blocoN330_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Histórico do Cheque - Feature REAC"
        self.nome = nome
        self.campos = RegistrosN330_subtipo01(bloco)


class blocoN330_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Histórico do Cheque - Feature REAC"
        self.nome = nome
        self.campos = RegistrosN330_subtipo02(bloco)


class blocoN330_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Histórico do Cheque - Feature REAC"
        self.nome = nome
        self.campos = RegistrosN330_subtipo99(bloco)


class blocoN400_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço de Agência Bancária"
        self.nome = nome
        self.campos = RegistrosN400_subtipo00(bloco)


class blocoN400_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço de Agência Bancária"
        self.nome = nome
        self.campos = RegistrosN400_subtipo01(bloco)


class blocoN400_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço de Agência Bancária"
        self.nome = nome
        self.campos = RegistrosN400_subtipo99(bloco)


class blocoN410_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do CEP"
        self.nome = nome
        self.campos = RegistrosN410_subtipo00(bloco)


class blocoN410_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do CEP"
        self.nome = nome
        self.campos = RegistrosN410_subtipo01(bloco)


class blocoN410_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do CEP"
        self.nome = nome
        self.campos = RegistrosN410_subtipo99(bloco)


class blocoN420_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do Telefone(Teleconfirma)"
        self.nome = nome
        self.campos = RegistrosN420_subtipo00(bloco)


class blocoN420_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do Telefone(Teleconfirma)"
        self.nome = nome
        self.campos = RegistrosN420_subtipo01(bloco)


class blocoN420_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do Telefone(Teleconfirma)"
        self.nome = nome
        self.campos = RegistrosN420_subtipo02(bloco)


class blocoN420_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Endereço do Telefone(Teleconfirma)"
        self.nome = nome
        self.campos = RegistrosN420_subtipo99(bloco)


class blocoN430_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Últimos telefones consultados"
        self.nome = nome
        self.campos = RegistrosN430_subtipo00(bloco)


class blocoN430_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Últimos telefones consultados"
        self.nome = nome
        self.campos = RegistrosN430_subtipo99(bloco)

class blocoN440_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registro de Consultas"
        self.nome = nome
        self.campos = RegistrosN440_subtipo00(bloco)


class blocoN440_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registro de Consultas"
        self.nome = nome
        self.campos = RegistrosN440_subtipo01(bloco)


class blocoN440_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registro de Consultas"
        self.nome = nome
        self.campos = RegistrosN440_subtipo02(bloco)


class blocoN440_subtipo03(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registro de Consultas"
        self.nome = nome
        self.campos = RegistrosN440_subtipo03(bloco)


class blocoN440_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Registro de Consultaas"
        self.nome = nome
        self.campos = RegistrosN440_subtipo99(bloco)


class blocoN460_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Ações Judiciais"
        self.nome = nome
        self.campos = RegistrosN460_subtipo00(bloco)


class blocoN460_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Ações Judiciais"
        self.nome = nome
        self.campos = RegistrosN460_subtipo01(bloco)


class blocoN460_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Ações Judiciais"
        self.nome = nome
        self.campos = RegistrosN460_subtipo02(bloco)


class blocoN460_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Ações Judiciais"
        self.nome = nome
        self.campos = RegistrosN460_subtipo90(bloco)


class blocoN460_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Ações Judiciais"
        self.nome = nome
        self.campos = RegistrosN460_subtipo99(bloco)


class blocoN470_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Falências / Concordatas"
        self.nome = nome
        self.campos = RegistrosN470_subtipo00(bloco)


class blocoN470_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Falências / Concordatas"
        self.nome = nome
        self.campos = RegistrosN470_subtipo90(bloco)


class blocoN470_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Falências / Concordatas"
        self.nome = nome
        self.campos = RegistrosN470_subtipo99(bloco)


class blocoN480_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação em Insucesso Empresarial"
        self.nome = nome
        self.campos = RegistrosN480_subtipo00(bloco)


class blocoN480_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação em Insucesso Empresarial"
        self.nome = nome
        self.campos = RegistrosN480_subtipo01(bloco)


class blocoN480_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação em Insucesso Empresarial"
        self.nome = nome
        self.campos = RegistrosN480_subtipo90(bloco)


class blocoN480_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação em Insucesso Empresarial"
        self.nome = nome
        self.campos = RegistrosN480_subtipo99(bloco)


class blocoN500_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Score"
        self.nome = nome
        self.campos = RegistrosN500_subtipo00(bloco)


class blocoN505_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Score"
        self.nome = nome
        self.campos = RegistrosN505_subtipo00(bloco)


class blocoN505_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Score"
        self.nome = nome
        self.campos = RegistrosN505_subtipo01(bloco)


class blocoN505_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Score"
        self.nome = nome
        self.campos = RegistrosN505_subtipo99(bloco)


class blocoN600_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo00(bloco)


class blocoN600_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo01(bloco)


class blocoN600_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo02(bloco)


class blocoN600_subtipo03(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo03(bloco)


class blocoN600_subtipo04(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo04(bloco)


class blocoN600_subtipo05(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Gestão de Crédito por Cheques"
        self.nome = nome
        self.campos = RegistrosN600_subtipo05(bloco)


class blocoN610_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Concentre Scoring PJ"
        self.nome = nome
        self.campos = RegistrosN610_subtipo00(bloco)


class blocoN610_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Concentre Scoring PJ"
        self.nome = nome
        self.campos = RegistrosN610_subtipo99(bloco)


class blocoN620_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Limite de Crédito PJ"
        self.nome = nome
        self.campos = RegistrosN620_subtipo00(bloco)


class blocoN620_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Limite de Crédito PJ"
        self.nome = nome
        self.campos = RegistrosN620_subtipo90(bloco)


class blocoN620_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Limite de Crédito PJ"
        self.nome = nome
        self.campos = RegistrosN620_subtipo99(bloco)


class blocoN630_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "AlertScoring PJ"
        self.nome = nome
        self.campos = RegistrosN630_subtipo00(bloco)


class blocoN630_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "AlertScoring PJ"
        self.nome = nome
        self.campos = RegistrosN630_subtipo99(bloco)


class blocoN640_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Faturamento Presumido PJ"
        self.nome = nome
        self.campos = RegistrosN640_subtipo00(bloco)


class blocoN640_subtipo90(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Faturamento Presumido PJ"
        self.nome = nome
        self.campos = RegistrosN640_subtipo90(bloco)


class blocoN640_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Faturamento Presumido PJ"
        self.nome = nome
        self.campos = RegistrosN640_subtipo99(bloco)


class blocoN650_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Localizador de Endereço PJ"
        self.nome = nome
        self.campos = RegistrosN650_subtipo00(bloco)


class blocoN650_subtipo01(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Localizador de Endereço PJ"
        self.nome = nome
        self.campos = RegistrosN650_subtipo01(bloco)


class blocoN650_subtipo02(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Localizador de Endereço PJ"
        self.nome = nome
        self.campos = RegistrosN650_subtipo02(bloco)


class blocoN650_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Localizador de Endereço PJ"
        self.nome = nome
        self.campos = RegistrosN650_subtipo99(bloco)


class blocoN660_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Renda Presumida PF"
        self.nome = nome
        self.campos = RegistrosN660_subtipo00(bloco)


class blocoN660_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Renda Presumida PF"
        self.nome = nome
        self.campos = RegistrosN660_subtipo99(bloco)


class blocoN670_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Indicador de Operacionalidade PJ"
        self.nome = nome
        self.campos = RegistrosN670_subtipo00(bloco)


class blocoN670_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Indicador de Operacionalidade PJ"
        self.nome = nome
        self.campos = RegistrosN670_subtipo99(bloco)


class blocoN680_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Indice Relacionamento Mercado"
        self.nome = nome
        self.campos = RegistrosN680_subtipo00(bloco)


class blocoN680_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Indice Relacionamento Mercado"
        self.nome = nome
        self.campos = RegistrosN680_subtipo99(bloco)


class blocoN690_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação Societária"
        self.nome = nome
        self.campos = RegistrosN690_subtipo00(bloco)


class blocoN690_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Participação Societária"
        self.nome = nome
        self.campos = RegistrosN690_subtipo99(bloco)


class blocoN700_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Sócios e Acionistas"
        self.nome = nome
        self.campos = RegistrosN700_subtipo00(bloco)


class blocoN700_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = u"Sócios e Acionistas"
        self.nome = nome
        self.campos = RegistrosN700_subtipo99(bloco)


class blocoN705_subtipo00(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Administradores"
        self.nome = nome
        self.campos = RegistrosN705_subtipo00(bloco)


class blocoN705_subtipo99(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Administradores"
        self.nome = nome
        self.campos = RegistrosN705_subtipo99(bloco)


class blocoT999(Bloco):

    def __init__(self, nome, bloco):
        self.nome_bloco = "Trailler - Fim dos dados"
        self.nome = nome
        self.campos = RegistrosT999(bloco)



# -*- coding: utf-8 -*-
from erros import CampoInexistenteError


class Bloco(object):

    def __getitem__(self, key):
        campo = ([c for c in self.campos if c.indice == key or c.nome == key] or [None])[0]
        if not campo:
            print CampoInexistenteError(key)
        return campo.get(self)

    def __getattr__(self, name):
        campo = ([c for c in self.campos.campos if c._nome == name] or [None])[0]
        if not campo:
            print CampoInexistenteError().exibirErro(name)
        else:
            return campo._valor



# -*- coding: utf-8 -*-


class RegistrosB49C(object):
    protocolo = None
    codEstacaoChamadora = None
    numDocumentoConsultado = None
    tipoPessoaConsultado = None
    baseCons = None
    modalidade = None
    vlrConsul = None
    centroCusto = None
    codificado = None
    qtdRegistros = None
    conversa = None
    funcao = None
    tipoConsulta = None
    atualiza = None
    ident_term = None
    rescli = None
    delts = None
    cobra = None
    passa = None
    consCollec = None
    localizador = None
    docCredor = None
    qtdCheque = None
    endTel = None
    qtdCho1 = None
    scoCho1 = None
    tarCho1 = None
    naoCobrarBureau = None
    autoPosit = None
    bureauViaSiteTransacion = None
    querTel9Digtos = None
    ctaCorrent = None
    dgCtacorr = None
    agencia = None
    alerta = None
    logon = None
    viaInternet = None
    resposta = None
    periodoCompro = None
    periodoEndereco = None
    backtest = None
    dtQuality = None
    prdOrigem = None
    trnOrigem = None
    consultante = None
    tpOr = None
    cnpjSoftware = None
    filler = None
    qtdCompr = None
    negativos = None
    cheque = None
    dataConsul = None
    horaConsult = None
    totalReg = None
    qtdReg1 = None
    codTab = None
    itemTsDados = None
    tsDados = None
    tsScore1 = None
    tsBp49 = None
    tsAutor = None
    itemTsAutor = None
    itemTsScor1 = None
    itemTsBp49 = None
    itemTsDados2 = None
    tsDados2 = None
    fase1 = None
    fase2 = None
    dbTabela = None
    codAut = None
    operid = None
    reciCompr = None
    reciPagto = None
    filler2 = None
    acessRechq = None
    temOcorrenciaRecheque = None
    reservado = None

    def get_nome_bloco(self):
        return "Bloco Protocolo"


class RegistrosP002(object):
    tipoReg = None
    cod1 = None
    chave1 = None
    cod2 = None
    chave2 = None
    cod3 = None
    chave3 = None
    cod4 = None
    chave4 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco P002"


class RegistrosN001(object):
    tipoReg = None
    subtipo = None
    tipoConsulta = None
    transacaoConsulta = None
    solGrandeVarejo = None
    idCheque = None
    agrupa = None
    consultaSintetica = None
    reservado = None
    anotacoesResumo = None
    chaveConsulta = None
    fantasia = None
    statusBanco = None
    filler = None
    trataTel = None

    def get_nome_bloco(self):
        return "Bloco N001"


class RegistrosN002_subtipo00(object):
    tipoReg = None
    subtipo = None
    banco = None
    agencia = None
    contaCorrente = None
    chequeInicial = None
    digitoChequeInicial = None
    chequeFinal = None
    digitoChequeFinal = None
    cmc7Inicial = None
    cmc7Final = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N002 subtipo 00"


class RegistrosN002_subtipo01(object):
    tipoReg = None
    subtipo = None
    valorCheque = None
    dataVencimentoCheque = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N002 subtipo 01"


class RegistrosN003(object):
    tipoReg = None
    subtipo = None
    ddd = None
    telefone = None
    cep = None
    uf = None
    featScor = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N003"


class RegistrosN200_subtipo00(object):
    tipoReg = None
    subtipo = None
    nomeRazao = None
    dataNascFundacao = None
    situacaoDoc = None
    dataSituacaoDoc = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N200 subtipo 00"


class RegistrosN200_subtipo01(object):
    tipoReg = None
    subtipo = None
    nomeMae = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N200 subtipo 01"


class RegistrosN210_subtipo00(object):
    tipoReg = None
    subtipo = None
    numMensagem = None
    totalMensagem = None
    tipoDoc = None
    numDoc = None
    motivo = None
    dataOcorrencia = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N210 subtipo 00"


class RegistrosN210_subtipo01(object):
    tipoReg = None
    subtipo = None
    ddd1 = None
    fone1 = None
    ddd2 = None
    fone2 = None
    ddd3 = None
    fone3 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N210 subtipo 01"


class RegistrosN210_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR210 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N210 subtipo 99"


class RegistrosN220(object):
    tipoReg = None
    subtipo = None
    msgNadaConsta = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N220"


class RegistrosN230_subtipo00(object):
    tipoReg = None
    subtipo = None
    dataOcorrencia = None
    modalidade = None
    avalista = None
    tipoMoeda = None
    valor = None
    contrato = None
    origem = None
    siglaEmbratel = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N230 subtipo 00"


class RegistrosN230_subtipo90(object):
    tipoReg = None
    subtipo = None
    totalOcorrencias = None
    dataOcorrenciaAntiga = None
    dataOcorrenciaRecente = None
    valorTotal = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N230 subtipo 90"


class RegistrosN230_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR230 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N230 subtipo 99"


class RegistrosN240_subtipo00(object):
    tipoReg = None
    subtipo = None
    dataOcorrencia = None
    modalidade = None
    avalista = None
    tipoMoeda = None
    valor = None
    contrato = None
    origem = None
    siglaEmbratel = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N240 subtipo 00"


class RegistrosN240_subtipo01(object):
    tipoReg = None
    subtipo = None
    subjudice = None
    msgSubjudice = None
    tipoAnotacao = None
    codCadus = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N240 subtipo 01"


class RegistrosN240_subtipo90(object):
    tipoReg = None
    subtipo = None
    totalOcorrencias = None
    dataOcorrenciaAntiga = None
    dataOcorrenciaRecente = None
    valorTotal = None
    tipoAnotacao = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N240 subtipo 90"


class RegistrosN240_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR240 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N240 subtipo 99"


class RegistrosN250_subtipo00(object):
    tipoReg = None
    subtipo = None
    dataOcorrencia = None
    tipoMoeda = None
    valor = None
    cartorio = None
    cidade = None
    uf = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N250 subtipo 00"


class RegistrosN250_subtipo01(object):
    tipoReg = None
    subtipo = None
    subjudice = None
    msgSubjudice = None
    tipoAnotacao = None
    codCadus = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N250 subtipo 01"


class RegistrosN250_subtipo90(object):
    tipoReg = None
    subtipo = None
    totalOcorrencias = None
    dataOcorrenciaAntiga = None
    dataOcorrenciaRecente = None
    moeda = None
    valorTotal = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N250 subtipo 90"


class RegistrosN250_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR250 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N250 subtipo 99"


class RegistrosN270_subtipo00(object):
    tipoReg = None
    subtipo = None
    dataOcorrencia = None
    cheque = None
    alinea = None
    quantidade = None
    valor = None
    numBanco = None
    nomeBanco = None
    agencia = None
    cidade = None
    uf = None
    codCadus = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N270 subtipo 00"


class RegistrosN270_subtipo90(object):
    tipoReg = None
    subtipo = None
    totalOcorrencias = None
    dataOcorrenciaAntiga = None
    dataOcorrenciaRecente = None
    banco = None
    agencia = None
    nomeFantasiaBanco = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N270 subtipo 90"


class RegistrosN270_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR270 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N270 subtipo 99"


class RegistrosN440_subtipo00(object):
    tipoReg = None
    subtipo = None
    dataEmissaoPrimeiroChequeVista = None
    dataEmissaoUltimoChequeVista = None
    totalChequesUltimos15DiasPrazo = None
    totalChequesUltimos30DiasPrazo = None
    totalChequesUltimos60DiasPrazo = None
    totalChequesUltimos90DiasPrazo = None
    totalChequesPrazo = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N440 subtipo 00"


class RegistrosN440_subtipo01(object):
    tipoReg = None
    subtipo = None
    dataEmissaoPrimeiroChequeVista = None
    dataEmissaoUltimoChequeVista = None
    totalChequesUltimos15DiasPrazo = None
    totalChequesUltimos30DiasPrazo = None
    totalChequesUltimos60DiasPrazo = None
    totalChequesUltimos90DiasPrazo = None
    totalChequesPrazo = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N440 subtipo 01"


class RegistrosN440_subtipo02(object):
    tipoReg = None
    subtipo = None
    PrimeiroRecenteNomeEmpr = None
    PrimeiroRecenteData = None
    SegundoRecenteNomeEmpr = None
    SegundoRecenteData = None
    TericeiroRecenteNomeEmpr = None
    TericeiroRecenteData = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N440 subtipo 02"


class RegistrosN440_subtipo03(object):
    tipoReg = None
    subtipo = None
    qtdConsultaUltimos15Dias = None
    qtdConsultaUltimos30Dias = None
    qtdConsultaUltimos60Dias = None
    qtdConsultaUltimos90Dias = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N440 subtipo 03"


class RegistrosN440_subtipo99(object):
    tipoReg = None
    subtipo = None
    msgR440 = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco N440 subtipo 99"


class RegistrosT999(object):
    tipoReg = None
    codigo = None
    mensagem = None
    filler = None

    def get_nome_bloco(self):
        return "Bloco T999"



# -*- coding: utf-8 -*-
from erros import BlocoInexistenteError
from blocosDados import pendenciasInternas
from blocosDados import pendenciasFinanceiras
from blocosDados import protestosEstados
from blocosDados import chequesSemFundos


class Crednet(object):
    def __init__(self):
        self.blocos = []
        self.blocos.append(pendenciasInternas())
        self.blocos.append(pendenciasFinanceiras())
        self.blocos.append(protestosEstados())
        self.blocos.append(chequesSemFundos())

    def __getattr__(self, name):
        bloco = ([c for c in self.blocos if c.nome == name] or [None])[0]
        if not bloco:
            print BlocoInexistenteError().exibirErro(name)
        else:
            if bloco.nome == 'pendenciasInternas':
                print bloco.nome_bloco + "\n"
                for registro in bloco.blocos:
                    for campos in registro.campos.campos:
                        print campos._nome,
                        print ": ",
                        print campos._valor

                    print " "
            if bloco.nome == 'pendenciasFinanceiras':
                print bloco.nome_bloco + "\n"
                for registro in bloco.blocos:
                    for campos in registro.campos.campos:
                        print campos._nome,
                        print ": ",
                        print campos._valor

                    print " "
            if bloco.nome == 'protestosEstados':
                print bloco.nome_bloco + "\n"
                for registro in bloco.blocos:
                    for campos in registro.campos.campos:
                        print campos._nome,
                        print ": ",
                        print campos._valor

                    print " "
            if bloco.nome == 'chequesSemFundos':
                print bloco.nome_bloco + "\n"
                for registro in bloco.blocos:
                    for campos in registro.campos.campos:
                        print campos._nome,
                        print ": ",
                        print campos._valor

                    print " "
            else:
                return bloco

    def get_string(self, bloco=None):
        string_retorno = ""
        if bloco is None:
            for bloco in self.blocos:
                if bloco.nome == 'pendenciasInternas':
                    string_retorno += "Pendencias Internas\n" + "------------" \
                             "-----------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                elif bloco.nome == 'pendenciasFinanceiras':
                    string_retorno += "Pendencias Financeiras\n" + "---------" \
                          "--------------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                elif bloco.nome == 'protestosEstados':
                    string_retorno += "Protestos dos Estados\n" + "---------" \
                          "--------------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                elif bloco.nome == 'chequesSemFundos':
                    string_retorno += "Cheques sem Fundos\n" + "-------------" \
                              "----------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                else:
                    string_retorno += bloco.nome_bloco + "-------------------" \
                                    "----------------------------------------\n"
                    for campo in bloco.campos.campos:
                        string_retorno += campo._nome + ": " + str(
                            campo._valor) + "\n"
            else:
                if bloco.nome == 'pendenciasInternas':
                    string_retorno += "Pendencias Internas\n" + "------------" \
                             "-----------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                        string_retorno += "\n"
                elif bloco.nome == '\npendenciasFinanceiras':
                    string_retorno += "Pendencias Financeiras\n" + "---------" \
                          "--------------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                        string_retorno += "\n"
                elif bloco.nome == 'protestosEstados':
                    string_retorno += "\nProtestos dos Estados\n" + "--------" \
                         "---------------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                    string_retorno += "\n"
                elif bloco.nome == 'chequesSemFundos':
                    string_retorno += "\nCheques sem Fundos\n" + "-----------" \
                            "------------------------------------------------\n"
                    for registro in bloco.blocos:
                        for campos in registro.campos.campos:
                            string_retorno += campos._nome + ": " + str(
                                campos._valor) + "\n"
                    string_retorno += "\n"
                elif bloco is not None:
                    string_retorno += "\n" + bloco.nome_bloco + "\n----------" \
                           "-------------------------------------------------\n"
                    for campo in bloco.campos.campos:
                        string_retorno += campo._nome + ": " + str(
                            campo._valor) + "\n"
                    string_retorno += "\n"
        return string_retorno

    def get_bloco_de_registros(self, nome):

        for bloco in self.blocos:
            if bloco.nome == nome:
                return bloco

        return None



# -*- coding: utf-8 -*-

from campos import Campo
from tiposCampos import campoData
from tiposCampos import campoDinheiro


class RegistrosB49C(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'protocolo', bloco, 4))
        self.campos.append(Campo(2, 4, 'codEstacaoChamadora', bloco, 6))
        self.campos.append(Campo(3, 10, 'numDocumentoConsultado', bloco, 15))
        self.campos.append(Campo(4, 25, 'tipoPessoaConsultado', bloco, 1))
        self.campos.append(Campo(5, 26, 'baseCons', bloco, 6))
        self.campos.append(Campo(6, 32, 'modalidade', bloco, 2))
        self.campos.append(Campo(7, 34, 'vlrConsul', bloco, 7))
        self.campos.append(Campo(8, 41, 'centroCusto', bloco, 12))
        self.campos.append(Campo(9, 53, 'codificado', bloco, 1))
        self.campos.append(Campo(10, 54, 'qtdRegistros', bloco, 2))
        self.campos.append(Campo(11, 56, 'conversa', bloco, 1))
        self.campos.append(Campo(12, 57, 'funcao', bloco, 3))
        self.campos.append(Campo(13, 60, 'tipoConsulta', bloco, 1))
        self.campos.append(Campo(14, 61, 'atualiza', bloco, 1))
        self.campos.append(Campo(15, 62, 'ident_term', bloco, 18))
        self.campos.append(Campo(16, 80, 'rescli', bloco, 10))
        self.campos.append(Campo(17, 90, 'delts', bloco, 1))
        self.campos.append(Campo(18, 91, 'cobra', bloco, 1))
        self.campos.append(Campo(19, 92, 'passa', bloco, 1))
        self.campos.append(Campo(20, 93, 'consCollec', bloco, 1))
        self.campos.append(Campo(21, 94, 'localizador', bloco, 1))
        self.campos.append(Campo(22, 95, 'docCredor', bloco, 9))
        self.campos.append(Campo(23, 104, 'qtdCheque', bloco, 2))
        self.campos.append(Campo(24, 106, 'endTel', bloco, 1))
        self.campos.append(Campo(25, 107, 'qtdCho1', bloco, 2))
        self.campos.append(Campo(26, 109, 'scoCho1', bloco, 1))
        self.campos.append(Campo(27, 110, 'tarCho1', bloco, 1))
        self.campos.append(Campo(28, 111, 'naoCobrarBureau', bloco, 1))
        self.campos.append(Campo(29, 112, 'autoPosit', bloco, 1))
        self.campos.append(Campo(30, 113, 'bureauViaSiteTransacional', bloco, 1))
        self.campos.append(Campo(31, 114, 'querTel9Digitos', bloco, 1))
        self.campos.append(Campo(32, 115, 'ctaCorrente', bloco, 10))
        self.campos.append(Campo(33, 125, 'dgCtaCorrente', bloco, 1))
        self.campos.append(Campo(34, 126, 'agencia', bloco, 4))
        self.campos.append(Campo(35, 130, 'alerta', bloco, 1))
        self.campos.append(Campo(36, 131, 'logon', bloco, 8))
        self.campos.append(Campo(37, 139, 'viaInternet', bloco, 1))
        self.campos.append(Campo(38, 140, 'resposta', bloco, 1))
        self.campos.append(Campo(39, 141, 'periodoCompro', bloco, 1))
        self.campos.append(Campo(40, 142, 'periodoEndereco', bloco, 1))
        self.campos.append(Campo(41, 143, 'backtest', bloco, 1))
        self.campos.append(Campo(42, 144, 'dtQuality', bloco, 1))
        self.campos.append(Campo(43, 145, 'prdOrigem', bloco, 2))
        self.campos.append(Campo(44, 147, 'trnOrigem', bloco, 4))
        self.campos.append(Campo(45, 151, 'consultante', bloco, 15))
        self.campos.append(Campo(46, 166, 'tpOr', bloco, 1))
        self.campos.append(Campo(47, 167, 'cnpjSoftware', bloco, 9))
        self.campos.append(Campo(48, 176, 'filler', bloco, 15))
        self.campos.append(Campo(49, 191, 'qtdCompr', bloco, 2))
        self.campos.append(Campo(50, 193, 'negativos', bloco, 1))
        self.campos.append(Campo(51, 194, 'cheque', bloco, 1))
        self.campos.append(campoData(52, 195, 'dataConsul', bloco, 8))
        self.campos.append(Campo(53, 203, 'horaConsul', bloco, 6))
        self.campos.append(Campo(54, 209, 'totalReg', bloco, 4))
        self.campos.append(Campo(55, 213, 'qtdReg1', bloco, 4))
        self.campos.append(Campo(56, 217, 'codTab', bloco, 4))
        self.campos.append(Campo(57, 221, 'itemTsDados', bloco, 4))
        self.campos.append(Campo(58, 225, 'tsDados', bloco, 16))
        self.campos.append(Campo(59, 241, 'tsScore1', bloco, 16))
        self.campos.append(Campo(60, 257, 'tsBp49', bloco, 16))
        self.campos.append(Campo(61, 273, 'tsAutor', bloco, 16))
        self.campos.append(Campo(62, 289, 'itemTsAutor', bloco, 4))
        self.campos.append(Campo(63, 293, 'itemTsScor1', bloco, 4))
        self.campos.append(Campo(64, 297, 'itemTsBp49', bloco, 4))
        self.campos.append(Campo(65, 301, 'itemTsDados2', bloco, 4))
        self.campos.append(Campo(66, 305, 'tsDados2', bloco, 16))
        self.campos.append(Campo(67, 321, 'fase1', bloco, 1))
        self.campos.append(Campo(68, 322, 'fase2', bloco, 1))
        self.campos.append(Campo(69, 323, 'dbTabela', bloco, 30))
        self.campos.append(Campo(70, 353, 'codAut', bloco, 1))
        self.campos.append(Campo(71, 354, 'operid', bloco, 3))
        self.campos.append(Campo(72, 357, 'reciCompr', bloco, 1))
        self.campos.append(Campo(73, 358, 'reciPagto', bloco, 1))
        self.campos.append(Campo(74, 359, 'filler2', bloco, 38))
        self.campos.append(Campo(75, 397, 'acessRechq', bloco, 1))
        self.campos.append(Campo(76, 398, 'temOcorrenciaRecheque', bloco, 1))
        self.campos.append(Campo(77, 399, 'reservado', bloco, 1))


class RegistrosP002(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'cod1', bloco, 4))
        self.campos.append(Campo(3, 8, 'chave1', bloco, 21))
        self.campos.append(Campo(4, 29, 'cod2', bloco, 4))
        self.campos.append(Campo(5, 33, 'chave2', bloco, 21))
        self.campos.append(Campo(6, 54, 'cod3', bloco, 4))
        self.campos.append(Campo(7, 58, 'chave3', bloco, 21))
        self.campos.append(Campo(8, 79, 'cod4', bloco, 4))
        self.campos.append(Campo(9, 83, 'chave4', bloco, 21))
        self.campos.append(Campo(10, 104, 'filler', bloco, 11))


class RegistrosN001(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subTipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoConsulta', bloco, 2))
        self.campos.append(Campo(4, 8, 'transacaoConsulta', bloco, 4))
        self.campos.append(Campo(5, 12, 'solGrandeVarejo', bloco, 1))
        self.campos.append(Campo(6, 13, 'idCheque', bloco, 1))
        self.campos.append(Campo(7, 14, 'agrupa', bloco, 1))
        self.campos.append(Campo(8, 15, 'consultaSintetica', bloco, 1))
        self.campos.append(Campo(9, 16, 'reservado', bloco, 1))
        self.campos.append(Campo(10, 17, 'anotacoesResumo', bloco, 1))
        self.campos.append(Campo(11, 18, 'chaveConsulta', bloco, 6))
        self.campos.append(Campo(12, 24, 'fantasia', bloco, 12))
        self.campos.append(Campo(13, 36, 'statusBanco', bloco, 1))
        self.campos.append(Campo(14, 37, 'filler', bloco, 13))
        self.campos.append(Campo(15, 50, 'trataTel', bloco, 1))
        self.campos.append(Campo(16, 51, 'filler', bloco, 64))


class RegistrosN002_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'banco', bloco, 3))
        self.campos.append(Campo(4, 9, 'agencia', bloco, 4))
        self.campos.append(Campo(5, 13, 'contaCorrente', bloco, 15))
        self.campos.append(Campo(6, 29, 'chequeInicial', bloco, 6))
        self.campos.append(Campo(7, 34, 'digitoChequeInicial', bloco, 1))
        self.campos.append(Campo(8, 35, 'chequeFinal', bloco, 6))
        self.campos.append(Campo(9, 41, 'digitoChequeFinal', bloco, 1))
        self.campos.append(Campo(10, 42, 'cmc7Inicial', bloco, 30))
        self.campos.append(Campo(11, 72, 'cmc7Final', bloco, 30))
        self.campos.append(Campo(12, 102, 'filler', bloco, 13))


class RegistrosN002_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoDinheiro(3, 6, 'valorCheque', bloco, 15))
        self.campos.append(campoData(4, 21, 'dataVencimentoCheque', bloco, 8))
        self.campos.append(Campo(5, 29, 'filler', bloco, 86))


class RegistrosN003(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 6))
        self.campos.append(Campo(3, 6, 'ddd', bloco, 3))
        self.campos.append(Campo(4, 9, 'telefone', bloco, 8))
        self.campos.append(Campo(5, 18, 'cep', bloco, 9))
        self.campos.append(Campo(6, 27, 'uf', bloco, 4))
        self.campos.append(Campo(7, 29, 'featScor', bloco, 80))
        self.campos.append(Campo(8, 109, 'filler', bloco, 6))


class RegistrosN200_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'nomeRazao', bloco, 70))
        self.campos.append(campoData(4, 76, 'dataNascFundacao', bloco, 8))
        self.campos.append(Campo(5, 84, 'situacaoDoc', bloco, 2))
        self.campos.append(campoData(6, 86, 'dataSituacaoDoc', bloco, 8))
        self.campos.append(Campo(7, 94, 'filler', bloco, 21))


class RegistrosN200_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'nomeMae', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN210_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'numMensagem', bloco, 2))
        self.campos.append(Campo(4, 8, 'totalMensagem', bloco, 2))
        self.campos.append(Campo(5, 10, 'tipoDoc', bloco, 6))
        self.campos.append(Campo(6, 16, 'numDoc', bloco, 20))
        self.campos.append(Campo(7, 36, 'motivo', bloco, 4))
        self.campos.append(campoData(8, 40, 'dataOcorrencia', bloco, 10))
        self.campos.append(Campo(9, 50, 'filler', bloco, 59))


class RegistrosN210_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 4))
        self.campos.append(Campo(3, 6, 'ddd1', bloco, 3))
        self.campos.append(Campo(4, 9, 'fone1', bloco, 8))
        self.campos.append(Campo(5, 17, 'ddd2', bloco, 3))
        self.campos.append(Campo(6, 21, 'fone2', bloco, 8))
        self.campos.append(Campo(7, 28, 'ddd3', bloco, 3))
        self.campos.append(Campo(8, 31, 'fone3', bloco, 8))
        self.campos.append(Campo(9, 39, 'filler', bloco, 76))


class RegistrosN210_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR210', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN220(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgNadaConsta', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN230_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'modalidade', bloco, 30))
        self.campos.append(Campo(5, 44, 'avalista', bloco, 1))
        self.campos.append(Campo(6, 45, 'tipoMoeda', bloco, 3))
        self.campos.append(campoDinheiro(7, 48, 'valor', bloco, 15))
        self.campos.append(Campo(8, 63, 'contrato', bloco, 16))
        self.campos.append(Campo(9, 79, 'origem', bloco, 30))
        self.campos.append(Campo(10, 109, 'siglaEmbratel', bloco, 4))
        self.campos.append(Campo(11, 113, 'filler', bloco, 2))


class RegistrosN230_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'totalOcorrencias', bloco, 5))
        self.campos.append(campoData(4, 11, 'dataOcorrenciaAntiga', bloco, 6))
        self.campos.append(campoData(5, 17, 'dataOcorrenciaRecente', bloco, 6))
        self.campos.append(campoDinheiro(6, 23, 'valorTotal', bloco, 15))
        self.campos.append(Campo(7, 38, 'filler', bloco, 77))


class RegistrosN230_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR230', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN240_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'modalidade', bloco, 30))
        self.campos.append(Campo(5, 44, 'avalista', bloco, 1))
        self.campos.append(Campo(6, 45, 'tipoMoeda', bloco, 3))
        self.campos.append(campoDinheiro(7, 48, 'valor', bloco, 15))
        self.campos.append(Campo(8, 63, 'contrato', bloco, 16))
        self.campos.append(Campo(9, 79, 'origem', bloco, 30))
        self.campos.append(Campo(10, 109, 'siglaEmbratel', bloco, 4))
        self.campos.append(Campo(11, 113, 'filler', bloco, 2))


class RegistrosN240_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'subjudice', bloco, 1))
        self.campos.append(Campo(4, 7, 'msgSubjudice', bloco, 76))
        self.campos.append(Campo(5, 83, 'tipoAnotacao', bloco, 1))
        self.campos.append(Campo(6, 84, 'codCadus', bloco, 10))
        self.campos.append(Campo(7, 94, 'filler', bloco, 21))


class RegistrosN240_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'totalOcorrencias', bloco, 5))
        self.campos.append(campoData(4, 11, 'dataOcorrenciaAntiga', bloco, 6))
        self.campos.append(campoData(5, 17, 'dataOcorrenciaRecente', bloco, 6))
        self.campos.append(campoDinheiro(6, 23, 'valorTotal', bloco, 15))
        self.campos.append(Campo(7, 38, 'tipoAnotacao', bloco, 1))
        self.campos.append(Campo(8, 39, 'filler', bloco, 16))


class RegistrosN240_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR240', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN250_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'tipoMoeda', bloco, 3))
        self.campos.append(campoDinheiro(5, 17, 'valor', bloco, 15))
        self.campos.append(Campo(6, 32, 'cartorio', bloco, 2))
        self.campos.append(Campo(7, 34, 'cidade', bloco, 30))
        self.campos.append(Campo(8, 64, 'uf', bloco, 2))


class RegistrosN250_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'subjudice', bloco, 1))
        self.campos.append(Campo(4, 7, 'msgSubjudice', bloco, 76))
        self.campos.append(Campo(5, 83, 'tipoAnotacao', bloco, 1))
        self.campos.append(Campo(6, 84, 'codCadus', bloco, 10))
        self.campos.append(Campo(7, 94, 'filler', bloco, 21))


class RegistrosN250_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'totalOcorrencias', bloco, 5))
        self.campos.append(campoData(4, 11, 'dataOcorrenciaAntiga', bloco, 6))
        self.campos.append(campoData(5, 17, 'dataOcorrenciaRecente', bloco, 6))
        self.campos.append(Campo(6, 23, 'moeda', bloco, 3))
        self.campos.append(campoDinheiro(7, 26, 'valorTotal', bloco, 15))
        self.campos.append(Campo(8, 41, 'filler', bloco, 74))


class RegistrosN250_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR250', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN270_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'cheque', bloco, 10))
        self.campos.append(Campo(5, 24, 'alinea', bloco, 5))
        self.campos.append(Campo(6, 29, 'quantidade', bloco, 5))
        self.campos.append(Campo(7, 34, 'valor', bloco, 15))
        self.campos.append(Campo(8, 49, 'numBanco', bloco, 3))
        self.campos.append(Campo(9, 52, 'nomeBanco', bloco, 14))
        self.campos.append(Campo(10, 66, 'agencia', bloco, 4))
        self.campos.append(Campo(11, 70, 'cidade', bloco, 30))
        self.campos.append(Campo(12, 100, 'uf', bloco, 2))
        self.campos.append(Campo(13, 102, 'codCadus', bloco, 10))
        self.campos.append(Campo(14, 112, 'filler', bloco, 3))


class RegistrosN270_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'totalOcorrencias', bloco, 5))
        self.campos.append(campoData(4, 11, 'dataOcorrenciaAntiga', bloco, 8))
        self.campos.append(campoData(5, 19, 'dataOcorrenciaRecente', bloco, 8))
        self.campos.append(Campo(6, 27, 'banco', bloco, 3))
        self.campos.append(Campo(7, 30, 'agencia', bloco, 4))
        self.campos.append(Campo(8, 34, 'nomeFantasiaBanco', bloco, 12))
        self.campos.append(Campo(9, 46, 'filler', bloco, 69))


class RegistrosN270_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR270', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN300_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 40))
        self.campos.append(campoData(4, 46, 'dataAbertura', bloco, 8))
        self.campos.append(Campo(5, 54, 'tipoPessoa', bloco, 1))
        self.campos.append(Campo(6, 55, 'numDoc', bloco, 15))
        self.campos.append(Campo(7, 70, 'nomeRazaoSocial', bloco, 40))
        self.campos.append(Campo(8, 110, 'filler', bloco, 5))


class RegistrosN300_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoDoc', bloco, 1))
        self.campos.append(Campo(4, 7, 'numDocIdentificacao', bloco, 15))
        self.campos.append(Campo(5, 22, 'orgaoEmissor', bloco, 5))
        self.campos.append(Campo(6, 27, 'ufDocIdentificacao', bloco, 2))
        self.campos.append(campoData(7, 29, 'dataEmissaoDocumento', bloco, 8))
        self.campos.append(Campo(8, 37, 'filler', bloco, 78))


class RegistrosN300_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'banco', bloco, 3))
        self.campos.append(Campo(4, 9, 'indicadorParticipacao', bloco, 1))
        self.campos.append(Campo(5, 10, 'msgR300', bloco, 36))
        self.campos.append(Campo(6, 46, 'filler', bloco, 69))


class RegistrosN310_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'banco', bloco, 3))
        self.campos.append(Campo(4, 9, 'agencia', bloco, 4))
        self.campos.append(Campo(5, 13, 'conta', bloco, 10))
        self.campos.append(Campo(6, 23, 'chequeInicial', bloco, 6))
        self.campos.append(Campo(7, 29, 'chequeFinal', bloco, 6))
        self.campos.append(Campo(8, 35, 'motivo', bloco, 12))
        self.campos.append(campoData(9, 47, 'dataCadastramento', bloco, 8))
        self.campos.append(Campo(10, 55, 'horaCadastramento', bloco, 4))
        self.campos.append(Campo(11, 59, 'codFonte', bloco, 4))
        self.campos.append(Campo(12, 63, 'filler', bloco, 52))


class RegistrosN310_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR310', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN320_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'banco', bloco, 3))
        self.campos.append(Campo(4, 9, 'agencia', bloco, 4))
        self.campos.append(Campo(5, 13, 'conta', bloco, 10))
        self.campos.append(Campo(6, 23, 'chequeInicial', bloco, 6))
        self.campos.append(Campo(7, 29, 'chequeFinal', bloco, 6))
        self.campos.append(Campo(8, 35, 'motivo', bloco, 12))
        self.campos.append(campoData(9, 47, 'dataCadastro', bloco, 8))
        self.campos.append(Campo(10, 55, 'codFonte', bloco, 4))
        self.campos.append(Campo(11, 59, 'filler', bloco, 56))


class RegistrosN320_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'totalOcorrencias', bloco, 5))
        self.campos.append(campoData(4, 11, 'dataOcorAntiga', bloco, 8))
        self.campos.append(campoData(5, 19, 'dataOcorRecente', bloco, 8))
        self.campos.append(Campo(6, 27, 'filler', bloco, 88))


class RegistrosN320_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR320', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN330_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'primeiraVerificacao', bloco, 1))
        self.campos.append(Campo(4, 7, 'numCheque', bloco, 6))
        self.campos.append(Campo(5, 13, 'qtdConsultasCheque', bloco, 3))
        self.campos.append(campoData(6, 16, 'dataAntiga', bloco, 8))
        self.campos.append(campoData(7, 24, 'dataRecente', bloco, 8))
        self.campos.append(Campo(8, 32, 'nomeEmpresa', bloco, 20))
        self.campos.append(Campo(9, 52, 'totalRegSegundaVerificacao', bloco, 3))
        self.campos.append(Campo(10, 55, 'totalRegContaCorrente', bloco, 3))
        self.campos.append(Campo(11, 58, 'filler', bloco, 57))


class RegistrosN330_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoDoc', bloco, 1))
        self.campos.append(Campo(4, 7, 'numDoc', bloco, 15))
        self.campos.append(Campo(5, 22, 'nomeRazao', bloco, 40))
        self.campos.append(Campo(6, 62, 'qtdConsultas', bloco, 3))
        self.campos.append(campoData(7, 65, 'dataOcorrenciaAntiga', bloco, 8))
        self.campos.append(campoData(8, 73, 'dataOcorrenciaRecente', bloco, 8))
        self.campos.append(Campo(9, 81, 'nomeEmpresaConsultante', bloco, 20))
        self.campos.append(Campo(10, 101, 'filler', bloco, 14))


class RegistrosN330_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoDoc', bloco, 1))
        self.campos.append(Campo(4, 7, 'numDoc', bloco, 15))
        self.campos.append(Campo(5, 22, 'nomeRazao', bloco, 40))
        self.campos.append(Campo(6, 62, 'qtdConsultas', bloco, 3))
        self.campos.append(Campo(7, 65, 'numUltimoCheque', bloco, 6))
        self.campos.append(campoData(8, 71, 'dataOcorrenciaAntiga', bloco, 8))
        self.campos.append(campoData(9, 79, 'dataOcorrenciaRecente', bloco, 8))
        self.campos.append(Campo(10, 87, 'filler', bloco, 28))


class RegistrosN330_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR330', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN400_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'nomeAgencia', bloco, 70))
        self.campos.append(Campo(4, 76, 'dataUltimaAtualizacao', bloco, 8))
        self.campos.append(Campo(5, 84, 'dddFone', bloco, 4))
        self.campos.append(Campo(6, 88, 'numFone', bloco, 8))
        self.campos.append(Campo(7, 96, 'dddFax', bloco, 4))
        self.campos.append(Campo(8, 100, 'numFax', bloco, 8))
        self.campos.append(Campo(9, 108, 'filler', bloco, 7))


class RegistrosN400_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'endAgencia', bloco, 70))
        self.campos.append(Campo(4, 76, 'cidade', bloco, 30))
        self.campos.append(Campo(5, 106, 'uf', bloco, 2))
        self.campos.append(Campo(6, 108, 'filler', bloco, 7))


class RegistrosN400_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR400', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN410_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'enderecoCep', bloco, 70))
        self.campos.append(Campo(4, 76, 'bairro', bloco, 30))
        self.campos.append(Campo(5, 106, 'filler', bloco, 9))


class RegistrosN410_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'cidade', bloco, 30))
        self.campos.append(Campo(4, 36, 'uf', bloco, 2))
        self.campos.append(Campo(5, 38, 'cepGenerico', bloco, 1))
        self.campos.append(Campo(6, 39, 'filler', bloco, 76))


class RegistrosN410_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR410', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN420_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 4))
        self.campos.append(Campo(3, 6, 'docConfere', bloco, 4))
        self.campos.append(Campo(4, 7, 'nomeAssinante', bloco, 4))
        self.campos.append(Campo(5, 77, 'tipoDocAssinante', bloco, 4))
        self.campos.append(Campo(6, 78, 'classeAssinante', bloco, 4))
        self.campos.append(campoData(7, 79, 'dataInstalacao', bloco, 4))
        self.campos.append(Campo(8, 87, 'filler', bloco, 4))


class RegistrosN420_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'logradouroAssinante', bloco, 70))
        self.campos.append(Campo(4, 76, 'bairroAssinante', bloco, 30))
        self.campos.append(Campo(5, 106, 'filler', bloco, 9))


class RegistrosN420_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'cidadeAssinante', bloco, 30))
        self.campos.append(Campo(4, 36, 'cepAssinante', bloco, 8))
        self.campos.append(Campo(5, 44, 'filler', bloco, 71))


class RegistrosN420_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'indicadorPesquisa', bloco, 1))
        self.campos.append(Campo(4, 7, 'msgR420', bloco, 40))
        self.campos.append(Campo(5, 47, 'filler', bloco, 68))


class RegistrosN430_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'ddd1', bloco, 3))
        self.campos.append(Campo(4, 9, 'fone1', bloco, 8))
        self.campos.append(Campo(5, 17, 'ddd2', bloco, 3))
        self.campos.append(Campo(6, 20, 'fone2', bloco, 8))
        self.campos.append(Campo(7, 28, 'ddd3', bloco, 3))
        self.campos.append(Campo(8, 31, 'fone3', bloco, 8))
        self.campos.append(Campo(9, 39, 'ddd4', bloco, 3))
        self.campos.append(Campo(10, 42, 'fone4', bloco, 8))
        self.campos.append(Campo(11, 50, 'ddd5', bloco, 3))
        self.campos.append(Campo(12, 53, 'fone5', bloco, 8))
        self.campos.append(Campo(13, 61, 'filler', bloco, 54))


class RegistrosN430_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR430', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN440_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataEmissaoPrimeiroChequeVista', bloco, 4))
        self.campos.append(campoData(4, 10, 'dataEmissaoUltimoChequeVista', bloco, 4))
        self.campos.append(Campo(5, 14, 'totalChequesUltimos15DiasPrazo', bloco, 3))
        self.campos.append(Campo(6, 17, 'totalChequesUltimos30DiasPrazo', bloco, 2))
        self.campos.append(Campo(7, 19, 'totalChequesUltimos60DiasPrazo', bloco, 2))
        self.campos.append(Campo(8, 21, 'totalChequesUltimos90DiasPrazo', bloco, 2))
        self.campos.append(Campo(9, 23, 'totalChequesPrazo', bloco, 3))
        self.campos.append(Campo(10, 26, 'filler', bloco, 89))


class RegistrosN440_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataEmissaoPrimeiroChequeVista', bloco, 4))
        self.campos.append(campoData(4, 10, 'dataEmissaoUltimoChequeVista', bloco, 4))
        self.campos.append(Campo(5, 14, 'totalChequesUltimos15DiasPrazo', bloco, 3))
        self.campos.append(Campo(6, 17, 'totalChequesUltimos30DiasPrazo', bloco, 2))
        self.campos.append(Campo(7, 19, 'totalChequesUltimos60DiasPrazo', bloco, 2))
        self.campos.append(Campo(8, 21, 'totalChequesUltimos90DiasPrazo', bloco, 2))
        self.campos.append(Campo(9, 23, 'totalChequesPrazo', bloco, 3))
        self.campos.append(Campo(10, 26, 'filler', bloco, 89))


class RegistrosN440_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'PrimeiroRecenteNomeEmpr', bloco, 25))
        self.campos.append(campoData(4, 31, 'PrimeiroRecenteData', bloco, 4))
        self.campos.append(Campo(5, 35, 'SegundoRecenteNomeEmpr', bloco, 25))
        self.campos.append(campoData(6, 60, 'SegundoRecenteData', bloco, 4))
        self.campos.append(Campo(7, 64, 'TericeiroRecenteNomeEmpr', bloco, 25))
        self.campos.append(campoData(8, 89, 'TericeiroRecenteData', bloco, 4))
        self.campos.append(Campo(9, 93, 'filler', bloco, 22))


class RegistrosN440_subtipo03(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'qtdConsultaUltimos15Dias', bloco, 3))
        self.campos.append(Campo(4, 9, 'qtdConsultaUltimos30Dias', bloco, 3))
        self.campos.append(Campo(5, 12, 'qtdConsultaUltimos60Dias', bloco, 3))
        self.campos.append(Campo(6, 15, 'qtdConsultaUltimos90Dias', bloco, 33))
        self.campos.append(Campo(7, 18, 'filler', bloco, 97))


class RegistrosN440_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR440', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 69))


class RegistrosN460_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'varaCivel', bloco, 4))
        self.campos.append(Campo(5, 18, 'numDistribuidor', bloco, 4))
        self.campos.append(Campo(6, 22, 'codNatureza', bloco, 3))
        self.campos.append(campoDinheiro(7, 25, 'valorAcao', bloco, 15))
        self.campos.append(Campo(8, 40, 'praca', bloco, 4))
        self.campos.append(Campo(9, 44, 'uf', bloco, 2))
        self.campos.append(Campo(10, 46, 'cidade', bloco, 30))
        self.campos.append(Campo(11, 76, 'principal', bloco, 1))
        self.campos.append(Campo(12, 77, 'subJudice', bloco, 1))
        self.campos.append(Campo(13, 78, 'filial', bloco, 4))
        self.campos.append(Campo(14, 82, 'digito', bloco, 2))
        self.campos.append(campoData(15, 84, 'dataInclusaoAnotacao', bloco, 8))
        self.campos.append(Campo(16, 92, 'horaInclusaoAnotacao', bloco, 6))
        self.campos.append(Campo(17, 98, 'chaveCadus', bloco, 10))
        self.campos.append(Campo(18, 108, 'filler', bloco, 7))


class RegistrosN460_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'descNatureza', bloco, 30))
        self.campos.append(Campo(4, 36, 'filler', bloco, 79))


class RegistrosN460_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'praca', bloco, 4))
        self.campos.append(Campo(4, 10, 'distribuidor', bloco, 2))
        self.campos.append(Campo(5, 12, 'vara', bloco, 2))
        self.campos.append(campoData(6, 14, 'data', bloco, 8))
        self.campos.append(Campo(7, 22, 'processo', bloco, 16))
        self.campos.append(Campo(8, 38, 'filler', bloco, 77))


class RegistrosN460_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataInicio', bloco, 8))
        self.campos.append(campoData(4, 14, 'dataFinal', bloco, 8))
        self.campos.append(Campo(5, 22, 'qtdTotal', bloco, 9))
        self.campos.append(campoDinheiro(6, 31, 'valorTotal', bloco, 15))
        self.campos.append(Campo(7, 46, 'filler', bloco, 69))


class RegistrosN460_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR460', bloco, 70))
        self.campos.append(Campo(4, 76, 'filler', bloco, 39))


class RegistrosN470_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'natureza', bloco, 2))
        self.campos.append(Campo(5, 16, 'vara', bloco, 4))
        self.campos.append(Campo(6, 20, 'praca', bloco, 4))
        self.campos.append(Campo(7, 24, 'uf', bloco, 2))
        self.campos.append(Campo(8, 26, 'cidade', bloco, 30))
        self.campos.append(Campo(9, 56, 'filial', bloco, 4))
        self.campos.append(Campo(10, 60, 'digito', bloco, 2))
        self.campos.append(campoData(11, 62, 'dataInclusao', bloco, 8))
        self.campos.append(Campo(12, 70, 'horaInclusao', bloco, 6))
        self.campos.append(Campo(13, 76, 'cadus', bloco, 10))
        self.campos.append(Campo(14, 86, 'descricaoNatureza', bloco, 29))


class RegistrosN470_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(campoData(3, 6, 'dataInicio', bloco, 8))
        self.campos.append(campoData(4, 14, 'dataFinal', bloco, 8))
        self.campos.append(Campo(5, 22, 'qtdTotal', bloco, 9))
        self.campos.append(campoDinheiro(6, 31, 'valorTotal', bloco, 15))
        self.campos.append(Campo(7, 46, 'filler', bloco, 69))


class RegistrosN470_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR470', bloco, 70))
        self.campos.append(Campo(4, 76, 'filler', bloco, 39))


class RegistrosN480_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'dataOcorrencia', bloco, 8))
        self.campos.append(Campo(4, 14, 'natureza', bloco, 2))
        self.campos.append(Campo(5, 16, 'qualificacao', bloco, 3))
        self.campos.append(Campo(6, 19, 'vara', bloco, 4))
        self.campos.append(Campo(7, 23, 'cnpj', bloco, 9))
        self.campos.append(Campo(8, 32, 'nomeEmpresa', bloco, 50))
        self.campos.append(Campo(9, 82, 'filial', bloco, 4))
        self.campos.append(Campo(10, 86, 'digito', bloco, 2))
        self.campos.append(Campo(11, 88, 'dataInclusao', bloco, 8))
        self.campos.append(Campo(12, 96, 'horaInclusao', bloco, 6))
        self.campos.append(Campo(13, 102, 'cadus', bloco, 10))
        self.campos.append(Campo(14, 112, 'filler', bloco, 3))


class RegistrosN480_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'descNatureza', bloco, 30))
        self.campos.append(Campo(4, 36, 'filler', bloco, 79))


class RegistrosN480_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 4))
        self.campos.append(campoData(3, 6, 'dataInicial', bloco, 4))
        self.campos.append(campoData(4, 14, 'dataFinal', bloco, 4))
        self.campos.append(Campo(5, 22, 'qtdTotal', bloco, 4))
        self.campos.append(campoDinheiro(6, 31, 'valorTotal', bloco, 4))
        self.campos.append(Campo(7, 46, 'filler', bloco, 4))


class RegistrosN480_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR480', bloco, 70))
        self.campos.append(Campo(4, 76, 'filler', bloco, 39))


class RegistrosN500_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 4))
        self.campos.append(Campo(3, 6, 'codScore', bloco, 4))
        self.campos.append(Campo(4, 10, 'scoreCalculado', bloco, 4))
        self.campos.append(Campo(5, 11, 'pontuacao', bloco, 4))
        self.campos.append(Campo(6, 17, 'msgR500', bloco, 4))
        self.campos.append(Campo(7, 87, 'delinRate', bloco, 4))
        self.campos.append(Campo(8, 92, 'range', bloco, 4))
        self.campos.append(Campo(9, 98, 'codMsg', bloco, 4))
        self.campos.append(Campo(10, 104, 'filler', bloco, 4))


class RegistrosN505_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'sequencia', bloco, 4))
        self.campos.append(Campo(4, 10, 'mensagem', bloco, 100))
        self.campos.append(Campo(5, 110, 'filler', bloco, 5))


class RegistrosN505_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'codScore', bloco, 2))
        self.campos.append(Campo(4, 8, 'mensagem', bloco, 100))
        self.campos.append(Campo(5, 108, 'filler', bloco, 7))


class RegistrosN505_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'codScore', bloco, 4))
        self.campos.append(Campo(4, 10, 'mensagem', bloco, 100))
        self.campos.append(Campo(5, 110, 'filler', bloco, 5))


class RegistrosN600_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'indicativoValCli', bloco, 1))
        self.campos.append(Campo(4, 7, 'valCliente', bloco, 15))
        self.campos.append(Campo(5, 22, 'valCheque', bloco, 15))
        self.campos.append(Campo(6, 37, 'indValorVista', bloco, 1))
        self.campos.append(Campo(7, 38, 'valorVista', bloco, 15))
        self.campos.append(Campo(8, 53, 'indValorPrazo', bloco, 1))
        self.campos.append(Campo(9, 54, 'valorPrazo', bloco, 15))
        self.campos.append(Campo(10, 69, 'indDataBloqueio', bloco, 1))
        self.campos.append(Campo(11, 70, 'dataBloqueio', bloco, 8))
        self.campos.append(Campo(12, 78, 'indLimiteIndividual', bloco, 1))
        self.campos.append(Campo(13, 79, 'indDataVip', bloco, 1))
        self.campos.append(Campo(14, 80, 'dataVip', bloco, 8))
        self.campos.append(Campo(15, 88, 'indCheques', bloco, 1))
        self.campos.append(Campo(16, 89, 'indFraude', bloco, 1))
        self.campos.append(Campo(17, 90, 'filler', bloco, 25))


class RegistrosN600_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'dataVencimento', bloco, 8))
        self.campos.append(Campo(4, 14, 'indCheque', bloco, 1))
        self.campos.append(Campo(5, 15, 'valorCheque', bloco, 15))
        self.campos.append(Campo(6, 30, 'dataCompra', bloco, 8))
        self.campos.append(Campo(7, 38, 'banco', bloco, 3))
        self.campos.append(Campo(8, 41, 'numCheque', bloco, 6))
        self.campos.append(Campo(9, 47, 'nomeCredor', bloco, 23))
        self.campos.append(Campo(10, 70, 'loja', bloco, 4))
        self.campos.append(Campo(11, 74, 'tipoDoc', bloco, 1))
        self.campos.append(Campo(12, 75, 'numDoc', bloco, 15))
        self.campos.append(Campo(13, 90, 'filler', bloco, 25))


class RegistrosN600_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'indValores', bloco, 1))
        self.campos.append(Campo(4, 7, 'mesano', bloco, 4))
        self.campos.append(Campo(5, 11, 'indValorVencer', bloco, 1))
        self.campos.append(campoDinheiro(6, 12, 'valorVencer', bloco, 15))
        self.campos.append(Campo(7, 27, 'indValorSaldo', bloco, 1))
        self.campos.append(campoDinheiro(8, 28, 'valorSaldo', bloco, 15))
        self.campos.append(Campo(9, 43, 'indValorLimite', bloco, 1))
        self.campos.append(campoDinheiro(10, 44, 'valorLimite', bloco, 15))
        self.campos.append(Campo(11, 59, 'indValorExcedente', bloco, 1))
        self.campos.append(campoDinheiro(12, 60, 'valorExcedente', bloco, 15))
        self.campos.append(Campo(13, 75, 'filler', bloco, 40))


class RegistrosN600_subtipo03(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 0, 'subtipo', bloco, 4))
        self.campos.append(Campo(3, 0, 'indTotalVencer', bloco, 4))
        self.campos.append(Campo(4, 0, 'totalVencer', bloco, 4))
        self.campos.append(Campo(5, 0, 'indSaldoVencer', bloco, 4))
        self.campos.append(Campo(6, 0, 'totalSaldoVencer', bloco, 4))
        self.campos.append(Campo(7, 0, 'indExcedenteVencer', bloco, 4))
        self.campos.append(Campo(8, 0, 'totalExcedenteVencer', bloco, 4))
        self.campos.append(Campo(9, 0, 'filler', bloco, 4))


class RegistrosN600_subtipo04(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'tipoReg', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoReg', bloco, 1))
        self.campos.append(Campo(4, 7, 'tipoReg', bloco, 15))
        self.campos.append(Campo(5, 22, 'tipoReg', bloco, 1))
        self.campos.append(Campo(6, 23, 'tipoReg', bloco, 15))
        self.campos.append(Campo(7, 38, 'tipoReg', bloco, 1))
        self.campos.append(Campo(8, 39, 'tipoReg', bloco, 15))
        self.campos.append(Campo(9, 54, 'tipoReg', bloco, 61))


class RegistrosN600_subtipo05(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'indTotalPrazo', bloco, 1))
        self.campos.append(Campo(4, 7, 'totalPrazo', bloco, 15))
        self.campos.append(Campo(5, 22, 'indSaldoPrazo', bloco, 1))
        self.campos.append(Campo(6, 23, 'totalSaldoPrazo', bloco, 15))
        self.campos.append(Campo(7, 38, 'indExcedentePrazo', bloco, 1))
        self.campos.append(Campo(8, 39, 'totalExcedentePrazo', bloco, 15))
        self.campos.append(Campo(9, 54, 'filler', bloco, 61))


class RegistrosN610_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'codScore', bloco, 4))
        self.campos.append(Campo(4, 10, 'pontuacao', bloco, 4))
        self.campos.append(Campo(5, 14, 'inadimplencia', bloco, 7))
        self.campos.append(Campo(6, 21, 'mensagem', bloco, 80))
        self.campos.append(Campo(7, 101, 'filler', bloco, 14))


class RegistrosN610_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 29))


class RegistrosN620_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'valorLimite', bloco, 13))
        self.campos.append(Campo(4, 19, 'filler', bloco, 96))


class RegistrosN620_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 30))


class RegistrosN620_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 40))
        self.campos.append(Campo(4, 46, 'filler', bloco, 30))


class RegistrosN630_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'classe', bloco, 1))
        self.campos.append(Campo(4, 7, 'pontuacao', bloco, 4))
        self.campos.append(Campo(5, 11, 'mensagem', bloco, 80))
        self.campos.append(Campo(6, 91, 'filler', bloco, 24))


class RegistrosN630_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'msgR630', bloco, 40))
        self.campos.append(Campo(4, 46, 'tipoReg', bloco, 29))


class RegistrosN640_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'valor', bloco, 18))
        self.campos.append(Campo(4, 24, 'filler', bloco, 90))


class RegistrosN640_subtipo90(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 100))
        self.campos.append(Campo(4, 106, 'filler', bloco, 8))


class RegistrosN640_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(4, 46, 'filler', bloco, 29))


class RegistrosN650_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'logradouro', bloco, 60))
        self.campos.append(Campo(4, 66, 'numero', bloco, 6))
        self.campos.append(Campo(5, 72, 'filler', bloco, 43))


class RegistrosN650_subtipo01(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'complemento', bloco, 40))
        self.campos.append(Campo(4, 66, 'bairro', bloco, 30))
        self.campos.append(Campo(5, 96, 'filler', bloco, 39))


class RegistrosN650_subtipo02(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'municipio', bloco, 30))
        self.campos.append(Campo(4, 36, 'cep', bloco, 8))
        self.campos.append(Campo(5, 44, 'uf', bloco, 2))
        self.campos.append(Campo(6, 48, 'ddd', bloco, 4))
        self.campos.append(Campo(7, 52, 'telefone', bloco, 9))
        self.campos.append(Campo(8, 61, 'filler', bloco, 56))


class RegistrosN650_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 4))
        self.campos.append(Campo(3, 6, 'tipoReg', bloco, 4))
        self.campos.append(Campo(4, 86, 'tipoReg', bloco, 4))


class RegistrosN660_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'renda', bloco, 9))
        self.campos.append(Campo(4, 15, 'mensagem', bloco, 80))
        self.campos.append(Campo(5, 95, 'filler', bloco, 20))


class RegistrosN660_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(4, 86, 'filler', bloco, 29))


class RegistrosN670_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'data', bloco, 8))
        self.campos.append(Campo(4, 14, 'filler', bloco, 101))


class RegistrosN670_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(4, 86, 'filler', bloco, 29))


class RegistrosN680_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'faixa', bloco, 2))
        self.campos.append(Campo(4, 8, 'mensagem', bloco, 72))
        self.campos.append(Campo(5, 80, 'filler', bloco, 35))


class RegistrosN680_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(4, 86, 'filler', bloco, 29))


class RegistrosN690_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'nome', bloco, 40))
        self.campos.append(Campo(4, 46, 'cnpj', bloco, 14))
        self.campos.append(Campo(5, 60, 'participacao', bloco, 5))
        self.campos.append(Campo(6, 65, 'uf', bloco, 2))
        self.campos.append(Campo(7, 67, 'dataInicio', bloco, 8))
        self.campos.append(Campo(8, 75, 'dataAtualizacao', bloco, 8))
        self.campos.append(Campo(9, 83, 'filler', bloco, 32))


class RegistrosN690_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(4, 87, 'filler', bloco, 29))


class RegistrosN700_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoPessoa', bloco, 1))
        self.campos.append(Campo(4, 7, 'docSocioAcionista', bloco, 14))
        self.campos.append(Campo(5, 21, 'nome', bloco, 60))
        self.campos.append(Campo(6, 81, 'capital', bloco, 4))
        self.campos.append(Campo(7, 85, 'filler', bloco, 30))


class RegistrosN700_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(1, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(1, 6, 'mensagem', bloco, 80))
        self.campos.append(Campo(1, 86, 'filler', bloco, 29))


class RegistrosN705_subtipo00(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'subtipo', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoPessoa', bloco, 1))
        self.campos.append(Campo(4, 7, 'docAdministrador', bloco, 14))
        self.campos.append(Campo(5, 21, 'nome', bloco, 60))
        self.campos.append(Campo(6, 81, 'cargo', bloco, 20))
        self.campos.append(Campo(7, 85, 'filler', bloco, 14))


class RegistrosN705_subtipo99(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'tipoReg', bloco, 2))
        self.campos.append(Campo(3, 6, 'tipoReg', bloco, 80))
        self.campos.append(Campo(4, 86, 'tipoReg', bloco, 29))


class RegistrosT999(object):

    def __init__(self, bloco):
        self.campos = []
        self.campos.append(Campo(1, 0, 'tipoReg', bloco, 4))
        self.campos.append(Campo(2, 4, 'codigo', bloco, 3))
        self.campos.append(Campo(3, 7, 'mensagem', bloco, 70))
        self.campos.append(Campo(4, 7, 'filler', bloco, 38))


# -*- coding: utf-8 -*-
import re
import requests


class ParserStringDados(object):

    def gerar_string_envio(self, documento_consultado,
                           tipo_pessoa_busca, documento_consultor, uf_cliente,
                           login, senha):
        
        dados = 'https://sitenet43.serasa.com.br/Prod/consultahttps?p=' \
                + login + senha + '        B49C      ' + documento_consultado +\
                tipo_pessoa_busca + 'C     FI0001000000000000000N99SINIAN    ' \
                                    '                          D             ' \
                                    'N                                       ' \
                                    '     ' \
                + documento_consultor + '                                    ' \
                                        '                                    ' \
                                        '                                    ' \
                                        '                                    ' \
                                        '                                    ' \
                                        '                                    ' \
                                        '                   P002RE02         ' \
                                        '                                    ' \
                                        '                                    ' \
                                        '                          N00100PPX2' \
                                        '1P 0                                ' \
                                        '                                    ' \
                                        '                                 ' \
                                        'N00300                     ' \
                + uf_cliente + '                                             ' \
                               '                                         T999'

        return dados

    def realizar_busca_serasa(self, dados):
        request = requests.get(dados, verify=False)

        return request.text

    def montar_bloco(self, bloco, arquivo):
        nome = bloco[0:4]
        nome_classe = "bloco"+nome
        if bloco[0:4] != u'B49C' and bloco[0:4] != u'T999' \
                and bloco[0:4] != u'P002' and bloco[0:4] != u'N001' \
                and bloco[0:4] != u'N003':
            nome_classe = nome_classe + "_subtipo" + bloco[4:6]
        mod_serializer = __import__('blocosDados', globals(), locals())
        func = getattr(mod_serializer, nome_classe)
        bloco_montado = func(nome, bloco)

        if nome == 'N230':
            arquivo.blocos[0].blocos.append(bloco_montado)
        elif nome == 'N240':
            arquivo.blocos[1].blocos.append(bloco_montado)
        elif nome == 'N250':
            arquivo.blocos[2].blocos.append(bloco_montado)
        elif nome == 'N270':
            arquivo.blocos[3].blocos.append(bloco_montado)
        else:
            arquivo.blocos.append(bloco_montado)

        return arquivo

    def parser_string_dados_retorno(self, string_dados_retorno, arquivo):
        string_dados_retorno = string_dados_retorno[
                               0:len(string_dados_retorno)-2] + 'T999'
        vetor_string_dados = re.findall(
            "([B,P,N]\d{2}.*?)(?=[B,P,N][1-9][0-9][0-9]|T999)", string_dados_retorno)

        arquivo_crednet = self.montar_objeto_crednet(
            vetor_string_dados, arquivo)

        return arquivo_crednet

    def montar_objeto_crednet(self, vetor_string_dados, arquivo):

        for bloco in vetor_string_dados:
            arquivo = self.montar_bloco(bloco, arquivo)

        return arquivo



# -*- coding: utf-8 -*-
from campos import Campo
import locale

class campoData(Campo):

     def __init__(self, indice, inicio, nome, bloco, tamanho):
        self._indice = indice
        self._nome = nome
        self._valor = self.mascaraData(bloco[inicio:inicio+tamanho])


     def mascaraData(self, valor):

        if len(valor) < 8:
            valor = valor[0:2] + "/" + valor[2:6]
        else:
            valor = valor[0:2] + "/" + valor[2:4] + "/" + valor[4:8]

        return valor


class campoDinheiro(Campo):

    def __init__(self, indice, inicio, nome, bloco, tamanho):
        self._indice = indice
        self._nome = nome
        self._valor = self.mascaraDinheiro(bloco[inicio:inicio+tamanho])

    def mascaraDinheiro(self, valor):

        valor = valor[0:len(valor)-2] + "." + valor[len(valor)-2:len(valor)]
        valor = float(valor)

        return valor


import setuptools
from distutils.core import setup


setup(
    name='pySerasa',
    version='0.1',
    license='MIT license',
    packages=['pyserasa'],
    url='https://github.com/kmee/pySerasa',
    author='KMEE',
    author_email='contato@kmee.com.br',
    description='Modulo para consulta de string de dados SERASA',
    setup_requires=['wheel'],
    install_requires=[
	'requests', 'locales',
    ],

)
